# V1alpha1Outputs

Outputs hold parameters, artifacts, and results from a step
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**artifacts** | [**list[V1alpha1Artifact]**](V1alpha1Artifact.md) | Artifacts holds the list of output artifacts produced by a step | [optional] 
**parameters** | [**list[V1alpha1Parameter]**](V1alpha1Parameter.md) | Parameters holds the list of output parameters produced by a step | [optional] 
**result** | **str** | Result holds the result (stdout) of a script template | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


